@@ -80,7 +80,7 @@ void IOSession::prep_fsync(int fd)
 	this->op = IO_CMD_FSYNC;
 }
 
-void IOSession::prep_fdsync(int fd)
+void IOSession::prep_fdatasync(int fd)
 {
 	this->fd = fd;
 	this->op = IO_CMD_FDSYNC;
@@ -104,6 +104,12 @@ int IOService::init(int maxevents)
 		return -1;
 	}
 
+	p = dlsym(RTLD_DEFAULT, "fdatasync");
+	if (p)
+		this->fdatasync = (int (*)(int))p;
+	else
+		this->fdatasync = fsync;
+
 	p = dlsym(RTLD_DEFAULT, "preadv");
 	if (p)
 		this->preadv = (ssize_t (*)(int, const struct iovec *, int, off_t))p;
@@ -216,15 +222,11 @@ void *IOService::io_routine(void *arg)
 	case IO_CMD_PWRITE:
 		ret = pwrite(fd, session->buf, session->count, session->offset);
 		break;
+	case IO_CMD_FSYNC:
 		ret = fsync(fd);
 		break;
 	case IO_CMD_FDSYNC:
-#if _POSIX_SYNCHRONIZED_IO > 0
-		ret = fdatasync(fd);
-		break;
-#endif
-	case IO_CMD_FSYNC:
-		ret = fsync(fd);
+		ret = service->fdatasync(fd);
 		break;
 	case IO_CMD_PREADV:
 		ret = service->preadv(fd, (const struct iovec *)session->buf,
