@@ -78,7 +78,7 @@ mpoller_t *mpoller_create(const struct poller_params *params, size_t nthreads)
 
 int mpoller_start(mpoller_t *mpoller)
 {
-	size_t i;
+	unsigned int i;
 
 	for (i = 0; i < mpoller->nthreads; i++)
 	{
@@ -95,9 +95,18 @@ int mpoller_start(mpoller_t *mpoller)
 	return -1;
 }
 
+void mpoller_set_callback(void (*callback)(struct poller_result *, void *),
+						  mpoller_t *mpoller)
+{
+	unsigned int i;
+
+	for (i = 0; i < mpoller->nthreads; i++)
+		poller_set_callback(callback, mpoller->poller[i]);
+}
+
 void mpoller_stop(mpoller_t *mpoller)
 {
-	size_t i;
+	unsigned int i;
 
 	for (i = 0; i < mpoller->nthreads; i++)
 		poller_stop(mpoller->poller[i]);
@@ -105,7 +114,7 @@ void mpoller_stop(mpoller_t *mpoller)
 
 void mpoller_destroy(mpoller_t *mpoller)
 {
-	size_t i;
+	unsigned int i;
 
 	for (i = 0; i < mpoller->nthreads; i++)
 		__poller_destroy(mpoller->poller[i]);
